"""Constants used throughout the pocketeer package."""

# Tessellation constants
MIN_ATOMS_FOR_TESSELLATION = 4

# Scoring constants
MIN_RADIUS_THRESHOLD = 3.5
MAX_RADIUS_THRESHOLD = 5.0

# I/O constants
ALPHABET_SIZE = 26

# Volume calculation constants
VOXEL_SIZE = 0.5
